[][src]Struct mini_haskell::input::Input

pub struct Input<I> { /* fields omitted */ }

Input with the ability to read one character once. Keeping such an iterator will prevent releasing the input resource.

Implementations

impl<I> Input<I>[src]

pub fn new(input: I) -> Self[src]

Create a new Input from a std::io::Read.

impl<I: Read> Input<I>[src]

pub fn next(
    self,
    report: impl FnMut(&[u8])
) -> Result<(char, Self), impl Into<Option<Error>>>
[src]

Get the next character, if any.

pub fn match(self, s: &str, report: impl FnMut(&[u8])) -> Option<Self>[src]

Match on the input, succeed if the input matches the given string.

pub fn dump(&self)[src]

Dump out the content of this input.